@@ -164,7 +164,7 @@ entry_changed (GtkWidget *w, GtkHTMLEditBodyProperties *data)
 		e->bgPixmapPtr = NULL;
 	}
 
-	fname = gtk_entry_get_text (GTK_ENTRY (w));
+	fname = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (w));
 	if (fname && *fname) {
 		gchar *file = gtk_html_filename_to_uri (fname);
 
@@ -185,7 +185,7 @@ changed_template (GtkWidget *w, GtkHTMLEditBodyProperties *d)
 	filename = (body_templates [template].bg_pixmap ?
 		    g_build_filename (ICONDIR, body_templates [template].bg_pixmap, NULL) :
 		    g_strdup (""));
-	gtk_entry_set_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (d->pixmap_entry))),
+	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER ((d->pixmap_entry)),
 			    filename);
 	g_free (filename);
 
@@ -236,7 +236,6 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 {
 	GtkHTMLEditBodyProperties *data = g_new0 (GtkHTMLEditBodyProperties, 1);
 	GtkWidget *main_vbox, *hbox, *combo, *label, *t1;
-	GSList *group;
 	HTMLColor *color;
 	gint i;
 
@@ -250,7 +249,6 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 	gtk_table_set_col_spacings (GTK_TABLE (t1), 6);
 	gtk_table_set_row_spacings (GTK_TABLE (t1), 6);
 
-	group = NULL;
 	i = 0;
 #define ADD_COLOR(x, ct, g) \
         color = html_colorset_get_color (cd->html->engine->settings->color_set, ct); \
@@ -263,6 +261,7 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 	hbox = gtk_hbox_new (FALSE, 3); \
         label = gtk_label_new_with_mnemonic (x); \
         gtk_misc_set_alignment (GTK_MISC (label), .0, .5); \
+        atk_object_add_relationship (gtk_widget_get_accessible (GI_COLOR_COMBO(combo)->preview_button), ATK_RELATION_LABELLED_BY, gtk_widget_get_accessible (label)); \
         gtk_table_attach (GTK_TABLE (t1), label, 0, 1, i, i + 1, GTK_FILL, GTK_FILL, 0, 0); \
         gtk_table_attach (GTK_TABLE (t1), combo, 1, 2, i, i + 1, GTK_FILL, GTK_FILL, 0, 0); \
         i ++
@@ -273,18 +272,18 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 
 	gtk_box_pack_start (GTK_BOX (main_vbox), editor_hig_vbox (_("Colors"), t1), FALSE, FALSE, 0);
 
-	data->pixmap_entry = gnome_pixmap_entry_new ("background_image", _("Background Image"), FALSE);
+	data->pixmap_entry = gtk_file_chooser_button_new (_("Background Image"), GTK_FILE_CHOOSER_ACTION_OPEN);
 	if (cd->html->engine->bgPixmapPtr) {
 		HTMLImagePointer *ip = (HTMLImagePointer *) cd->html->engine->bgPixmapPtr;
 		gchar *filename = gtk_html_filename_from_uri (ip->url);
 		
-		gtk_entry_set_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (data->pixmap_entry))),
+		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER ((data->pixmap_entry)),
 				    filename);
 		g_free (filename);
 	}
 
 
-	atk_object_set_name (gtk_widget_get_accessible (gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (data->pixmap_entry))), _("Background Image File Path"));
+	atk_object_set_name (gtk_widget_get_accessible (GTK_FILE_CHOOSER (data->pixmap_entry)), _("Background Image File Path"));
 
 	t1 = gtk_table_new (2, 2, FALSE);
 	gtk_table_set_col_spacings (GTK_TABLE (t1), 6);
@@ -319,8 +318,8 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
         g_signal_connect (data->combo [0], "color_changed", G_CALLBACK (color_changed), data);
         g_signal_connect (data->combo [1], "color_changed", G_CALLBACK (color_changed), data);
         g_signal_connect (data->combo [2], "color_changed", G_CALLBACK (color_changed), data);
-	g_signal_connect (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (data->pixmap_entry)),
-			  "changed", G_CALLBACK (entry_changed), data);
+	g_signal_connect (GTK_FILE_CHOOSER_BUTTON (data->pixmap_entry),
+			  "selection-changed", G_CALLBACK (entry_changed), data);
 
 	return main_vbox;
 }
